@@ -72,6 +72,9 @@ class PlotDataObject(DessiaObject):
                                                compute_for='class')
         return DessiaObject.dict_to_object(dict_=dict_, force_generic=True)
 
+    def plot_data(self):
+        raise NotImplementedError('It is strange to call plot_data method from a plot_data object.'
+                                  f' Check the class {self.__class__.__name__} you are calling')
 
 class HatchingSet(DessiaObject):
     """
@@ -231,17 +234,22 @@ class Text(PlotDataObject):
     :param max_width: Set a maximum length for the text. If the text \
     is longer than max_width, it is split into several lines.
     :type max_width: float
+    :param multi_lines: This parameter is only useful when max_width parameter is set \
+    In that case, you can choose between squishing the text in one line or writing on \
+    multiple lines.
+    :type multi_lines: bool
     """
 
     def __init__(self, comment: str, position_x: float, position_y: float,
                  text_style: TextStyle = None, text_scaling: bool = None,
-                 max_width: float = None, name: str = ''):
+                 max_width: float = None, multi_lines: bool = True, name: str = ''):
         self.comment = comment
         self.text_style = text_style
         self.position_x = position_x
         self.position_y = position_y
         self.text_scaling = text_scaling
         self.max_width = max_width
+        self.multi_lines = multi_lines
         PlotDataObject.__init__(self, type_='text', name=name)
 
     def mpl_plot(self, ax=None, color='k', alpha=1.):
@@ -353,6 +361,24 @@ class LineSegment(LineSegment2D):
                       DeprecationWarning)
 
 
+class Wire(PlotDataObject):
+    """
+    A set of connected lines. It also provides highlighting feature.
+    :param lines: [(x1, y1), ..., (xn,yn)]
+    :type lines: List[Tuple[float, float]]
+    :param edge_style: Line settings
+    :type edge_style: EdgeStyle
+    :param tooltip: a message that is displayed in a tooltip
+    :type tooltip: str
+    """
+    def __init__(self, lines: List[Tuple[float, float]], edge_style: EdgeStyle = None,
+                 tooltip: str = None, name: str = ""):
+        self.lines = lines
+        self.edge_style = edge_style
+        self.tooltip = tooltip
+        PlotDataObject.__init__(self, type_="wire", name=name)
+
+
 class Circle2D(PlotDataObject):
     """
     A circle. It is a primitive and can be instantiated by PrimitiveGroup.
@@ -367,17 +393,21 @@ class Circle2D(PlotDataObject):
     :type edge_style: EdgeStyle
     :param surface_style: customization of the circle's interior
     :type surface_style: SurfaceStyle
+    :param tooltip: tooltip message
+    :type tooltip: str
     """
 
     def __init__(self, cx: float, cy: float, r: float,
                  edge_style: EdgeStyle = None,
                  surface_style: SurfaceStyle = None,
+                 tooltip: str = None,
                  name: str = ''):
         self.edge_style = edge_style
         self.surface_style = surface_style
         self.r = r
         self.cx = cx
         self.cy = cy
+        self.tooltip = tooltip
         PlotDataObject.__init__(self, type_='circle', name=name)
 
     def bounding_box(self):
@@ -498,11 +528,13 @@ class Tooltip(PlotDataObject):
     :type tooltip_radius: float
     """
 
-    def __init__(self, attributes: List[str],
+    def __init__(self, attributes: List[str] = None,
+                 text: str = None,
                  surface_style: SurfaceStyle = None,
                  text_style: TextStyle = None, tooltip_radius: float = None,
                  name: str = ''):
         self.attributes = attributes
+        self.text = text
         self.surface_style = surface_style
         if surface_style is None:
             self.surface_style = SurfaceStyle(color_fill=colors.LIGHTBLUE,
@@ -606,6 +638,24 @@ class Graph2D(PlotDataObject):
         return ax
 
 
+class Heatmap(DessiaObject):
+    """
+    Heatmap is a scatter plot's view. This class contains the Heatmap's parameters.
+    :param size: A tuple of two integers corresponding to the number of squares on the horizontal and vertical sides.
+    :type size: Tuple[int, int]
+    :param colors: The list of colors ranging from low density to high density, e.g. colors=[colors.BLUE, colors.RED] \
+    so the low density areas tend to be blue while higher density areas tend to be red.
+    :type colors: List[Colors]
+    :param edge_style: The areas separating lines settings
+    :type edge_style: EdgeStyle
+    """
+    def __init__(self, size: Tuple[int, int]=None, colors:List[colors.Color]=None, edge_style:EdgeStyle=None, name:str=''):
+        self.size = size
+        self.colors = colors
+        self.edge_style = edge_style
+        DessiaObject.__init__(self, name=name)
+
+
 class Scatter(PlotDataObject):
     """
     A class for drawing scatter plots.
@@ -629,6 +679,11 @@ class Scatter(PlotDataObject):
     :type log_scale_x: bool
     :param log_scale_y: True or False
     :type log_scale_y: bool
+    :param heatmap: Heatmap view settings
+    :type heatmap: Heatmap
+    :param heatmap_view: Heatmap view when loading the object. If set \
+    to False, you'd still be able to enable it using the button.
+    :type heatmap_view: bool
     """
 
     def __init__(self, x_variable: str, y_variable: str,
@@ -636,6 +691,7 @@ class Scatter(PlotDataObject):
                  point_style: PointStyle = None,
                  elements: List[Any] = None, axis: Axis = None,
                  log_scale_x: bool = None, log_scale_y: bool = None,
+                 heatmap: Heatmap = None, heatmap_view: bool = None,
                  name: str = ''):
         self.tooltip = tooltip
         self.attribute_names = [x_variable, y_variable]
@@ -650,9 +706,22 @@ class Scatter(PlotDataObject):
             self.axis = axis
         self.log_scale_x = log_scale_x
         self.log_scale_y = log_scale_y
+        self.heatmap = heatmap
+        self.heatmap_view = heatmap_view
         PlotDataObject.__init__(self, type_='scatterplot', name=name)
 
 
+class ScatterMatrix(PlotDataObject):
+    def __init__(self, elements: List[Any] = None, axes: List[str] = None,
+                 point_style: PointStyle = None, surface_style: SurfaceStyle = None,
+                 name: str = ""):
+        self.elements = elements
+        self.axes = axes
+        self.point_style = point_style
+        self.surface_style = surface_style
+        PlotDataObject.__init__(self, type_="scattermatrix", name=name)
+
+
 class Arc2D(PlotDataObject):
     """
     A class for drawing arcs. Arc2D is a primitive and can be \
@@ -732,14 +801,17 @@ class Contour2D(PlotDataObject):
     :type edge_style: EdgeStyle
     :param surface_style: for customizing the interior of the contour
     :type surface_style: SurfaceStyle
+    :param tooltip: A message that is displayed in a tooltip
+    :type tooltip: str
     """
 
     def __init__(self, plot_data_primitives: List[Union[Arc2D, LineSegment2D]],
                  edge_style: EdgeStyle = None,
-                 surface_style: SurfaceStyle = None, name: str = ''):
+                 surface_style: SurfaceStyle = None, tooltip: str = None, name: str = ''):
         self.plot_data_primitives = plot_data_primitives
         self.edge_style = edge_style
         self.surface_style = surface_style
+        self.tooltip = tooltip
         PlotDataObject.__init__(self, type_='contour', name=name)
 
     def bounding_box(self):
@@ -811,11 +883,11 @@ class PrimitiveGroup(PlotDataObject):
     :param primitives: a list of Contour2D, Arc2D, LineSegment2D, \
     Circle2D, Line2D or MultipleLabels
     :type primitives: List[Union[Contour2D, Arc2D, LineSegment2D, \
-    Circle2D, Line2D, MultipleLabels]]
+    Circle2D, Line2D, MultipleLabels, Wire]]
     """
 
-    def __init__(self, primitives: List[Union[Contour2D, Arc2D, LineSegment2D,
-                                              Circle2D, Line2D]],
+    def __init__(self, primitives: List[Union[Contour2D, Arc2D, LineSegment2D, \
+    Circle2D, Line2D, MultipleLabels, Wire]],
                  name: str = ''):
         self.primitives = primitives
         PlotDataObject.__init__(self, type_='primitivegroup', name=name)
@@ -1072,6 +1144,8 @@ def plot_canvas(plot_data_object: Subclass[PlotDataObject],
         template = templates.primitive_group_container_template
     elif plot_type == 'histogram':
         template = templates.histogram_template
+    elif plot_type == "scattermatrix":
+        template = templates.scatter_matrix_template
     else:
         raise NotImplementedError('Type {} not implemented'.format(plot_type))
 
@@ -1130,7 +1204,7 @@ TYPE_TO_CLASS = {'arc': Arc2D, 'axis': Axis, 'circle': Circle2D,  # Attribute
                  'graphs2D': Graph2D, 'linesegment2d': LineSegment,
                  'multiplot': MultiplePlots, 'parallelplot': ParallelPlot,
                  'point': Point2D, 'scatterplot': Scatter, 'tooltip': Tooltip,
-                 'primitivegroup': PrimitiveGroup}
+                 'primitivegroup': PrimitiveGroup, "scattermatrix": ScatterMatrix}
 
 
 def bounding_box(plot_datas: Subclass[PlotDataObject]):
